///
///  WSGraphPlotFactory.h
///  PowerPlot
///
///  This category defines a series of factory methods providing
///  common designs for charts with bar plots. The user can choose
///  several default styles and methods to display the data. Note that
///  it is still possible to configure all properties of charts
///  generated this way and that it is similarly possible to add
///  custom plots, too. An important point to be aware of is that an
///  autogenerated chart usually employs the design pattern that each
///  plot in the chart delegates to a single data set and coordinate
///  system only!  When adding custom plots the user may or may not
///  adhere to this convention.
///
///
///  Created by Wolfram Schroers on 20.10.10.
///  Copyright 2010 Numerik & Analyse Schroers. All rights reserved.
///

#import <Foundation/Foundation.h>
#import "WSChart.h"
#import "WSPlotFactoryDefaults.h"


@class WSGraph;

@interface WSChart (WSGraphPlotFactory)

/** Return an autoreleased chart with a graph (nodes and connections). */
+ (id)graphPlotWithFrame:(CGRect)frame
                   graph:(WSGraph *)data
             colorScheme:(LPColorScheme)colors;

/** @brief Configure the current graph instance.
 
    The instance will have all previous data removed and contain a
    graph plot with appropriate configuration.

    @param data The input data set containing the nodes.
    @param colors The color scheme of the resulting chart.
 */
- (void)configureWithGraph:(WSGraph *)data
               colorScheme:(LPColorScheme)colors;

@end
